# Edit this configuration file to define what should be installed on
# your system.  Help is available in the configuration.nix(5) man page
# and in the NixOS manual (accessible by running ‘nixos-help’).

{ config, pkgs, lib, ... }:

# let smol = import <nixos-unstable-small> {config.allowUnfree = true;};
with lib;
with builtins;
{
  imports = [ ./modules ];
  nixpkgs.config.allowUnfree = true;

  nixpkgs.overlays = [
    (import (builtins.fetchTarball "https://github.com/PrismLauncher/PrismLauncher/archive/develop.tar.gz")).overlay
  ];

  nix = {
    package = pkgs.nixVersions.stable;
    extraOptions = ''
      experimental-features = nix-command flakes
      keep-outputs = true
      keep-derivations = true
    '';
  };


  time.timeZone = "Europe/Berlin";

  networking.networkmanager.enable = true;  # Easiest to use and most distros use this by default.
  networking.networkmanager.wifi.backend = "iwd";
  networking.extraHosts = ''
      127.0.0.1 www.youtube.com
      127.0.0.1 www.reddit.com
      127.0.0.1 www.tiktok.com
      127.0.0.1 www.twitter.com
      127.0.0.1 www.instagram.com
      127.0.0.1 www.facebook.com
      127.0.0.1 www.snapchat.com

      127.0.0.1 youtube.com
      127.0.0.1 reddit.com
      127.0.0.1 tiktok.com
      127.0.0.1 twitter.com
      127.0.0.1 instagram.com
      127.0.0.1 facebook.com
      127.0.0.1 snapchat.com

      127.0.0.1 google-analytics.com
      127.0.0.1 stats.g.doubleclick.net
      127.0.0.1 googleadservices.com
      127.0.0.1 googletagmanager.com
      127.0.0.1 googletagservices.com
      127.0.0.1 googlesyndication.com
    '';

  home-manager.users.jade = { nixosConfig, pkgs, ... }: {
    home.sessionVariables.TZ = nixosConfig.time.timeZone;
  };

  nixpkgs.config.packageOverrides = pkgs: {
    sudo = pkgs.sudo.override { withInsults = true; };
  };
  security.sudo.extraConfig = "Defaults insults";

  services.xserver = {
    enable = true;

    wacom.enable = true;
    libinput = {
      enable = true;
    };

    desktopManager = {
      xterm.enable = false;
    };
   
    displayManager = {
      defaultSession = "none+i3";
      gdm.enable = true;
    };

    windowManager.i3 = {
      enable = true;
      package = pkgs.i3-gaps;
      extraPackages = with pkgs; [
        gnome.gdm i3lock-fancy rofi rofimoji volumeicon feh xorg.xinput dunst
        arandr lxappearance gruvbox-dark-gtk gruvbox-dark-icons-gtk 
        gruvterial-theme flameshot tesseract5 imagemagick xclip polybar kitty
        xkeysnail gtk-engine-murrine playerctl xmacro
        libwacom wacomtablet xorg.xev
      ];
    };
  };
  programs.dconf.enable = true;
  programs.kdeconnect.enable = true;
  programs.corectrl.enable = true;

  qt5.platformTheme = "qt5ct";

  virtualisation.libvirtd.enable = true;

  boot.plymouth = {
    enable = true;
    #theme = "glow";
  };

  hardware.opengl.enable = true;

  services.xserver.layout = "us";
  services.xserver.xkbVariant = "altgr-intl";
  hardware.uinput.enable = true;

  services.printing.enable = true;

  security.rtkit.enable = true;
  services.pipewire = {
    enable = true;
    alsa.enable = true;
    #alsa.support32Bit = true;
    pulse.enable = true;
    jack.enable = true;
  };

  hardware.bluetooth.enable = true;
  hardware.keyboard.uhk.enable = true;

  hardware.spacenavd.enable = true;

  environment.sessionVariables = rec {
    QT_QPA_PLATFORMTHEME = "qt5ct";
    TERMINAL = "kitty";
  };
users.users.jade = {
    isNormalUser = true;
    extraGroups = [ "wheel" "input" "uinput" "libvirtd" ];
    packages = with pkgs; [
    ];
  };

  zramSwap = {
    enable = true;
    algorithm = "zstd";
  };


  # missing: picom-jonaburg
  environment.systemPackages = with pkgs; [
    # spotify-tui jetbrains.webstorm jetbrains.datagrip jetbrains.idea-ultimate jetbrains.pycharm-professional python3Full jetbrains.clion 
    wget git neofetch pciutils pavucontrol font-manager zip unzip gnutar iw
    btop xdotool xorg.xwininfo nodejs gparted networkmanagerapplet mailspring
    betterdiscordctl pulseaudioFull speedtest-cli librewolf firefox jdk8 jdk11
    jdk vlc xfce.thunar xfce.tumbler xfce.thunar-archive-plugin
    gnome.file-roller uhk-agent spotify spotify-tray cool-retro-term lutris
    libsecret gh xorg.xhost helvum xdg-desktop-portal-gtk nheko obsidian
    nix-prefetch-scripts audacity rustup easyeffects virt-manager evince direnv
    nix-direnv fzf openrgb krita gmic-qt-krita gimp-with-plugins
    inkscape-with-extensions virglrenderer ddccontrol-db glab
    firebird-emu obs-studio kdenlive openal
    mullvad mullvad-vpn
    sl lolcat ifuse 
    fspy spacenav-cube-example 
    cava appimage-run
    spacenavd libspnav fluent-reader
    #prismlauncher
    evolution
    godot
    gitg gnome-builder git-crypt
    gpick qdirstat file whois ffmpeg_5 scribus p7zip file nmap cmatrix tree socat libreoffice
  ];

  programs.noisetorch.enable = true;

  environment.pathsToLink = [
    "/share/nix-direnv"
  ];

  services.flatpak.enable = true;
  xdg.portal.enable = true;
  xdg.portal.extraPortals = [ pkgs.xdg-desktop-portal-gtk ];

  fonts.fonts = with pkgs; [
    nerdfonts montserrat noto-fonts atkinson-hyperlegible
  ];

  programs.mtr.enable = true;
  programs.gnupg.agent = {
    enable = true;
    enableSSHSupport = true;
  };

  programs.zsh.enable = true;
  users.defaultUserShell = pkgs.zsh;

  services.openssh.enable = true;

  services.mullvad-vpn.enable = true;

  services.gnome.gnome-keyring.enable = true;
  programs.seahorse.enable = true;
  security.pam.services.jade.enableGnomeKeyring = true;

  # Copy the NixOS configuration file and link it from the resulting system
  # (/run/current-system/configuration.nix). This is useful in case you
  # accidentally delete configuration.nix.
  # system.copySystemConfiguration = true;

  networking.firewall.allowedTCPPorts = [ 8384 22000 ];
  networking.firewall.allowedUDPPorts = [ 8080 22000 21027 ];
  systemd.services."NetworkManager-wait-online".enable = false;

  services.syncthing = rec {
    enable = true;
    user = "jade";
    dataDir = "/home/${user}/Documents";
    configDir = "/home/${user}/Documents/.config/syncthing";
  };
}

